@@ -67,6 +67,12 @@ impl Environment {
     pub fn clone_variables(env: &Environment) -> EnvironmentVariables {
         env.variables.clone()
     }
+
+    pub fn append_variables(env: &Environment, variables: EnvironmentVariables) -> Environment {
+        let mut new_env = Environment::new(Environment::clone_variables(env));
+        new_env.variables.extend(variables);
+        new_env
+    }
 }
 
 #[cfg(test)]
