@@ -2,6 +2,7 @@ use super::{node::NodeProvider, Provider};
 use crate::nixpacks::{
     app::App,
     environment::{Environment, EnvironmentVariables},
+    images::DEBIAN_BASE_IMAGE,
     nix::pkg::Pkg,
     plan::{
         phase::{Phase, StartPhase},
@@ -10,6 +11,7 @@ use crate::nixpacks::{
 };
 use anyhow::{bail, Ok, Result};
 use regex::Regex;
+use semver::Version;
 
 pub struct RubyProvider {}
 
@@ -51,6 +53,11 @@ impl Provider for RubyProvider {
 
         plan.add_variables(self.get_environment_variables(app)?);
 
+        // Temporary fix to allow using older versions of ruby
+        if self.requires_openssl_1(app)? {
+            plan.build_image = Some(DEBIAN_BASE_IMAGE.to_string());
+        }
+
         Ok(Some(plan))
     }
 }
@@ -80,6 +87,8 @@ impl RubyProvider {
             setup.add_apt_pkgs(vec![String::from("libicu-dev")]);
         }
 
+        let ruby_version = self.get_ruby_version(app)?;
+
         setup.add_cmd(format!(
             "curl -sSL https://get.rvm.io | bash -s stable \
             && . /etc/profile.d/rvm.sh \
@@ -87,7 +96,7 @@ impl RubyProvider {
             && rvm --default use {ruby_version} \
             && gem install {bundler_version} \
             && rm -rf /usr/local/rvm/src",
-            ruby_version = self.get_ruby_version(app)?,
+            ruby_version = ruby_version,
             bundler_version = self.get_bundler_version(app)
         ));
 
@@ -215,6 +224,21 @@ impl RubyProvider {
         }
     }
 
+    fn requires_openssl_1(&self, app: &App) -> Result<bool> {
+        let ruby_version = self.get_ruby_version(app)?;
+        match Version::parse(ruby_version.trim_start_matches("ruby-")) {
+            std::result::Result::Ok(v) => {
+                // Version 3.1.0 and above work with openssl 3.0
+                if v.major >= 3 && v.minor >= 1 {
+                    Ok(false)
+                } else {
+                    Ok(true)
+                }
+            }
+            std::result::Result::Err(_) => Ok(false),
+        }
+    }
+
     fn is_rails_app(&self, app: &App) -> bool {
         app.includes_file("config/application.rb")
             && app
